@@ -3,9 +3,8 @@ package Carp::Growl;
 use warnings;
 use strict;
 use Carp;
-use Smart::Comments;
 
-use version; our $VERSION = '0.0.5';
+use version; our $VERSION = '0.0.6';
 
 use Growl::Any;
 
@@ -188,7 +187,7 @@ Carp::Growl - Send warnings to Growl
 
 =head1 VERSION
 
-This document describes Carp::Growl version 
+This document describes Carp::Growl version 0.0.6
 
 
 =head1 SYNOPSIS
